==> entest-cdk-chatbot-0.0.0.tar.gz: entest-cdk-chatbot-0.0.0/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "entest-cdk-chatbot",
    "version": "0.0.0",
    "description": "entest-cdk-chatbot",
    "license": "Apache-2.0",
    "url": "https://github.com/hai/entest-cdk-chatbot.git",
    "long_description_content_type": "text/markdown",
    "author": "haitran<hai@entest.io>",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/hai/entest-cdk-chatbot.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "entest_cdk_chatbot",
        "entest_cdk_chatbot._jsii"
    ],
    "package_data": {
        "entest_cdk_chatbot._jsii": [
            "entest-cdk-chatbot@0.0.0.jsii.tgz"
        ],
        "entest_cdk_chatbot": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.7",
    "install_requires": [
        "aws-cdk-lib>=2.87.0, <3.0.0",
        "constructs>=10.0.5, <11.0.0",
        "jsii>=1.87.0, <2.0.0",
        "publication>=0.0.3",
        "typeguard~=2.13.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Typing :: Typed",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)

==> entest-cdk-chatbot-0.0.1.tar.gz: entest-cdk-chatbot-0.0.1/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "entest-cdk-chatbot",
    "version": "0.0.1",
    "description": "entest-cdk-chatbot",
    "license": "Apache-2.0",
    "url": "https://github.com/entest-hai/entest-cdk-chatbot.git",
    "long_description_content_type": "text/markdown",
    "author": "haitran<hai@entest.io>",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/entest-hai/entest-cdk-chatbot.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "entest_cdk_chatbot",
        "entest_cdk_chatbot._jsii"
    ],
    "package_data": {
        "entest_cdk_chatbot._jsii": [
            "entest-cdk-chatbot@0.0.1.jsii.tgz"
        ],
        "entest_cdk_chatbot": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.7",
    "install_requires": [
        "aws-cdk-lib>=2.87.0, <3.0.0",
        "constructs>=10.0.5, <11.0.0",
        "jsii>=1.87.0, <2.0.0",
        "publication>=0.0.3",
        "typeguard~=2.13.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Typing :: Typed",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)
